@@ -2,11 +2,11 @@ from typing import List
 import smtplib
 import ssl
 
-from magicapi import settings
+from magicapi import g
 
 
-port, smtp_server = settings.email_port, settings.email_smtp_server
-sender_email, sender_password = settings.sender_email, settings.sender_password
+port, smtp_server = g.settings.email_port, g.settings.email_smtp_server
+sender_email, sender_password = g.settings.sender_email, g.settings.sender_password
 from magicapi.Decorators.background_tasks import run_in_background
 
 
